"use client"
import { Button, Input, Modal, ModalBody, ModalContent, ModalFooter, ModalHeader } from "@nextui-org/react";
import useContacts from "@/feature/messenger/hooks/useContacts";
import { useTranslation } from "@/hooks/useTranslation";
import usePermissionChat from "@/feature/messenger/hooks/usePermissionChat";

const Contacts = () => {

    const { trans } = useTranslation();
    const {
        openModalEditContact,
        toggleContacts,
        formContacts,
        hadlerChangeForm,
        handleSubmitContacts,
        dissmiss,
        selectedConversation,
        isExistsContact,
        loading,
    } = useContacts();
    const permission = usePermissionChat();

    // Función auxiliar para agrupar campos en pares
    const renderFieldPair = (fields: JSX.Element[], pairIndex: number) => {
        return (
            <div className="grid grid-cols-2 gap-2 m-1">
                {fields.map((field, index) => (
                    <div key={`${pairIndex}-${index}`}>
                        <div className="form-group">
                            {field}
                        </div>
                    </div>
                ))}
                {fields.length === 1 && <div key="empty-field"></div>}
            </div>
        );
    };

    // Función para obtener todos los campos visibles
    const getVisibleFields = () => {
        const fields = [
            // El nombre siempre está visible
            <Input 
                key="name"
                className="form-control" 
                label={trans("modal_conversations_contacts_input_name_label")} 
                type="text" 
                name="name" 
                value={formContacts.name} 
                onChange={hadlerChangeForm} 
                required 
                placeholder={trans("modal_conversations_contacts_input_name_label")} 
            />,
            // Resto de campos condicionados por permisos
            permission.crea_agenda_email && (
                <Input 
                    label={trans("modal_conversations_contacts_input_email_label")} 
                    className="form-control" 
                    type="text" 
                    name="email" 
                    value={formContacts.email} 
                    onChange={hadlerChangeForm} 
                    placeholder={trans("modal_conversations_contacts_input_email_label")} 
                />
            ),
            permission.crea_agenda_ciudad && (
                <Input 
                    label={trans("modal_conversations_contacts_input_city_label")} 
                    className="form-control" 
                    type="text" 
                    name="city" 
                    value={formContacts.city} 
                    onChange={hadlerChangeForm} 
                    placeholder={trans("modal_conversations_contacts_input_city_label")} 
                />
            ),
            permission.crea_agenda_direccion && (
                <Input 
                    label={trans("modal_conversations_contacts_input_address_label")} 
                    className="form-control" 
                    type="text" 
                    name="address" 
                    value={formContacts.address} 
                    onChange={hadlerChangeForm} 
                    placeholder={trans("modal_conversations_contacts_input_address_label")} 
                />
            ),
            permission.crea_agenda_status && (
                <Input 
                    label={trans("modal_conversations_contacts_input_state_label")} 
                    className="form-control" 
                    type="text" 
                    name="state" 
                    value={formContacts.state} 
                    onChange={hadlerChangeForm} 
                    placeholder={trans("modal_conversations_contacts_input_state_label")} 
                />
            ),
            permission.crea_agenda_campo1 && (
                <Input 
                    label={trans("modal_conversations_contacts_input_management1_label")} 
                    className="form-control" 
                    type="text" 
                    name="management1" 
                    value={formContacts.management1} 
                    onChange={hadlerChangeForm} 
                    placeholder={trans("modal_conversations_contacts_input_management1_label")} 
                />
            ),
            permission.crea_agenda_campo2 && (
                <Input 
                    label={trans("modal_conversations_contacts_input_management2_label")} 
                    className="form-control" 
                    type="text" 
                    name="management2" 
                    value={formContacts.management2} 
                    onChange={hadlerChangeForm} 
                    placeholder={trans("modal_conversations_contacts_input_management2_label")} 
                />
            )
        ].filter(Boolean); // Elimina los campos false

        return fields;
    };

    // Función para renderizar los campos en pares
    const renderFieldPairs = () => {
        const visibleFields = getVisibleFields();
        const pairs = [];

        for (let i = 0; i < visibleFields.length; i += 2) {
            const pair = visibleFields.slice(i, i + 2) as JSX.Element[];
            pairs.push(renderFieldPair(pair, i));
        }

        return pairs;
    };

    return (
        <>
            <Modal
                isOpen={openModalEditContact}
                onOpenChange={() => toggleContacts()}
                size="2xl"
            >
                <ModalContent>
                    {(onClose) => (
                        <>
                            <ModalHeader>
                                <i data-feather="bar-chart-2"></i>{trans("modal_conversations_contacts_title")}
                            </ModalHeader>
                            <form onSubmit={(e) => handleSubmitContacts(e)} onSubmitCapture={(e) => e.preventDefault()}>
                                <ModalBody className="p-4">

                                    <div className="w-full gap-2">
                                        {dissmiss && (
                                            <div className="flex items-center p-4 mb-4 text-sm text-yellow-800 rounded-lg bg-yellow-50 dark:bg-gray-800 dark:text-yellow-300" role="alert">
                                            <svg className="flex-shrink-0 inline w-4 h-4 me-3" aria-hidden="true" xmlns="http://www.w3.org/2000/svg" fill="currentColor" viewBox="0 0 20 20">
                                              <path d="M10 .5a9.5 9.5 0 1 0 9.5 9.5A9.51 9.51 0 0 0 10 .5ZM9.5 4a1.5 1.5 0 1 1 0 3 1.5 1.5 0 0 1 0-3ZM12 15H8a1 1 0 0 1 0-2h1v-3H8a1 1 0 0 1 0-2h2a1 1 0 0 1 1 1v4h1a1 1 0 0 1 0 2Z"/>
                                            </svg>
                                            <span className="sr-only">Info</span>
                                            <div>
                                              <h4 className="alert-heading">{trans("modal_conversations_contacts_notify_first_part_title")} <strong>{selectedConversation?.sesion}</strong> {trans("modal_conversations_contacts_notify_second_part_title")}</h4>
                                            </div>
                                          </div>
                                        )}

                                        {renderFieldPairs()}
                                    </div>

                                </ModalBody>
                                <ModalFooter>
                                    <Button color="danger" variant="light" isDisabled={loading} onPress={toggleContacts}>
                                        {trans('modal_conversations_contacts_button_cancel_label')}
                                    </Button>
                                    <Button color="primary" isLoading={loading} type="submit">
                                        {loading ? trans('modal_conversations_contacts_button_create_loading_label') : isExistsContact ? trans('modal_conversations_contacts_button_edit_label') : trans('modal_conversations_contacts_button_create_label')}
                                    </Button>
                                </ModalFooter>
                            </form>
                        </>
                    )}
                </ModalContent>
            </Modal >
        </>
    )
}

export default Contacts